@@ -15,13 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Callable, Dict, Optional
+from typing import TYPE_CHECKING, Any, Callable, Optional, Sequence
 
 from jira.resources import Issue, Resource
 
 from airflow.providers.jira.operators.jira import JIRAError, JiraOperator
 from airflow.sensors.base import BaseSensorOperator
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class JiraSensor(BaseSensorOperator):
@@ -29,16 +31,11 @@ class JiraSensor(BaseSensorOperator):
     Monitors a jira ticket for any change.
 
     :param jira_conn_id: reference to a pre-defined Jira Connection
-    :type jira_conn_id: str
     :param method_name: method name from jira-python-sdk to be execute
-    :type method_name: str
     :param method_params: parameters for the method method_name
-    :type method_params: dict
     :param result_processor: function that return boolean and act as a sensor response
-    :type result_processor: function
     """
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -63,7 +60,7 @@ class JiraSensor(BaseSensorOperator):
             result_processor=self.result_processor,
         )
 
-    def poke(self, context: Dict) -> Any:
+    def poke(self, context: 'Context') -> Any:
         return self.jira_operator.execute(context=context)
 
 
@@ -72,20 +69,14 @@ class JiraTicketSensor(JiraSensor):
     Monitors a jira ticket for given change in terms of function.
 
     :param jira_conn_id: reference to a pre-defined Jira Connection
-    :type jira_conn_id: str
     :param ticket_id: id of the ticket to be monitored
-    :type ticket_id: str
     :param field: field of the ticket to be monitored
-    :type field: str
     :param expected_value: expected value of the field
-    :type expected_value: str
     :param result_processor: function that return boolean and act as a sensor response
-    :type result_processor: function
     """
 
-    template_fields = ("ticket_id",)
+    template_fields: Sequence[str] = ("ticket_id",)
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -106,7 +97,7 @@ class JiraTicketSensor(JiraSensor):
 
         super().__init__(jira_conn_id=jira_conn_id, result_processor=field_checker_func, **kwargs)
 
-    def poke(self, context: Dict) -> Any:
+    def poke(self, context: 'Context') -> Any:
         self.log.info('Jira Sensor checking for change in ticket: %s', self.ticket_id)
 
         self.jira_operator.method_name = "issue"
@@ -116,7 +107,7 @@ class JiraTicketSensor(JiraSensor):
     def issue_field_checker(self, issue: Issue) -> Optional[bool]:
         """Check issue using different conditions to prepare to evaluate sensor."""
         result = None
-        try:  # pylint: disable=too-many-nested-blocks
+        try:
             if issue is not None and self.field is not None and self.expected_value is not None:
 
                 field_val = getattr(issue.fields, self.field)
@@ -136,7 +127,7 @@ class JiraTicketSensor(JiraSensor):
 
         except JIRAError as jira_error:
             self.log.error("Jira error while checking with expected value: %s", jira_error)
-        except Exception:  # pylint: disable=broad-except
+        except Exception:
             self.log.exception("Error while checking with expected value %s:", self.expected_value)
         if result is True:
             self.log.info(
